#!/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_bf133961-9e91-4b30-8f82-635789a81accsib993ix/croots/anaconda-navigator/anaconda-navigator_1653376611694/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_bf133961-9e91-4b30-8f82-635789a81accsib993ix/croots/anaconda-navigator/anaconda-navigator_1653376611694/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/bin/anaconda-navigator"])
